# -*- coding: iso_8859_1 -*-

from aspylib import astro, conf
import numpy as np
import matplotlib.pyplot as plt

#------------------------------------------------------------------------------------
#	purpose
#------------------------------------------------------------------------------------
#
#	This script is an example showing how to modify a single FITS image and save the modified image under a different name.
#	In this particular example, the user is invited to select a rectangle in the image. Then in the selected area all the pixel levels are replaced with the median value of the whole image.
#	This script can be used to make a cosmetic correction (i.e. remove a cosmic ray impact on one image).
#
#------------------------------------------------------------------------------------
#	input parameters
#------------------------------------------------------------------------------------

Image = conf.folder + "image_in.fit"
Image2 = conf.folder + "image_out.fit"

#------------------------------------------------------------------------------------
#	cosmetic correction on input image
#------------------------------------------------------------------------------------

#------- loading image + headers ------
im = astro.get_imagedata([Image])
headerdict = astro.get_headers([Image], text_display=False)

#------ selecting area to be corrected ------
print("")
print('Select upper-left and lower-right corners of the rectangular area to be removed from the image')
xy = astro.select(im, nb=2, facecolor='red', marker='+')
print(xy)
xmin = np.min([xy[0][0], xy[1][0]])
xmax = np.max([xy[0][0], xy[1][0]])
ymin = np.min([xy[0][1], xy[1][1]])
ymax = np.max([xy[0][1], xy[1][1]])

#------ implementing correction and displaying new image ------
med = astro.get_median(im)
im[xmin:xmax, ymin:ymax] = med
astro.display(im)

#------ saving corrected image -----
astro.save_imagelist(im, headerdict, [Image2])
print("")
print(Image2, "saved")
