# -*- coding: iso_8859_1 -*-

import matplotlib.pyplot as plt
from aspylib import astro, calib, conf

#------------------------------------------------------------------------------------
#	purpose
#------------------------------------------------------------------------------------
#
#	This script loads a list of calibrated images and co-align them.
#
#------------------------------------------------------------------------------------
#	input parameters
#------------------------------------------------------------------------------------

#--- folders and imagenames ---
Folder = conf.folder+"test_calibration\\"
Imagelist = [Folder + "processed\\images\\ngc7635-calibrated-" + str(i+1) + ".fits" for i in range(30)]
Imagelist2 = [Folder + "processed\\images\\ngc7635-coaligned-" + str(i+1) + ".fits" for i in range(30)]

#--- additional information (for FITS headers) ---
Config = 0
Headers = {'OBJECT': ['ngc7635 (coaligned)','']}

#------------------------------------------------------------------------------------
#	script
#------------------------------------------------------------------------------------

#--- loading and co-aligning images ---
images = astro.get_imagedata(Imagelist)	
images_aligned, shifts = calib.coalign(images, fit_area=10, nb_stars=24, excl=[], incl=[], text_display=False, return_shifts=True)
print("")
print("images co-aligned")

#save images
headerdictlist = astro.create_headers(Config, Imagelist)
newheaderdictlist = []
for headerdict in headerdictlist:
	headerdict.update(Headers)
	newheaderdictlist.append(headerdict)
	
#saving calibrated images
astro.save_imagelist(images_aligned, newheaderdictlist, Imagelist2)
print("")
print("co-aligned images saved")

#displaying the shifts
plt.figure()
plt.plot(shifts[:,0], label='X')
plt.plot(shifts[:,1], label='Y')
plt.legend()
plt.show()