# -*- coding: iso_8859_1 -*-

from aspylib import astro, conf
import numpy as np

#------------------------------------------------------------------------------------
#	Purpose
#------------------------------------------------------------------------------------
#
#	This script calculates the statistics of a series of offset frames (i.e. acquired with shutter closed, zero exposure).
#	- for each image it calculates the mean value, and then the mean of all means
#	- for each pair of successive images, it calculates the read-out noise (rms value of the difference image, divided by sqrt(2)), and then the mean of all read-out noises
#
#------------------------------------------------------------------------------------
#	Input parameters
#------------------------------------------------------------------------------------

Imagelist = [conf.folder + "offset-" + str(i+1) + ".fits" for i in range(20)]

#------------------------------------------------------------------------------------
#	Script
#------------------------------------------------------------------------------------
#loading images
bias = astro.get_imagedata(Imagelist)

#calculating mean values
mean = np.mean(np.mean(bias, axis=1), axis=1)
print("")
print("-----------------------------------------------")
print("Mean values")
print("-----------------------------------------------")
print(mean)
print(np.mean(mean))

#calculating RO noise
ROnoise = np.zeros(len(Imagelist)-1) 
for i in range(0,len(Imagelist)-1):
	x = bias[i+1,:,:]-bias[i,:,:]	
	ROnoise[i] = np.std(x.flatten())/np.sqrt(2.)
print("")
print("-----------------------------------------------")
print("Read-out noise values")
print("-----------------------------------------------")
print(ROnoise)
print(np.mean(ROnoise))
