# -*- coding: iso_8859_1 -*-

from aspylib import astro, conf
import numpy as np
import os, time

#------------------------------------------------------------------------------------
#	Purpose
#------------------------------------------------------------------------------------
#
#	this scripts detects all new FITS files written to the specified folder
#	it computes their
#	- min, mean and max values
#	- median PSF fwhm (small, large) over the detected stars
#
#------------------------------------------------------------------------------------
#	Input parameters
#------------------------------------------------------------------------------------

#path information
path_to_watch = conf.folder + "test\\"

#fit parameters
margin = 12
fit_area = 12
nb_stars = 12

#------------------------------------------------------------------------------------
#	Script
#------------------------------------------------------------------------------------

#loop to detect new fits files created in folder
before = dict ([(f, None) for f in os.listdir (path_to_watch)]) 
while 1: 
	time.sleep (10) 
	after = dict ([(f, None) for f in os.listdir (path_to_watch)]) 
	added = [f for f in after if not f in before] 
	#if added: print("Added: ", ", ".join (added))
	before = after 

	for f in added:
		if astro.check_extension(f):
			#loading new images
			image = astro.get_imagedata([path_to_watch+f])
			
			#calculating statistics
			mean = np.mean(image.flatten())
			maxi = np.max(image.flatten())
			mini = np.min(image.flatten())
			print("                   min: ", mini, "     max: ", maxi, "     mean: ", mean)

			#fitting stars
			stars = astro.find_stars(image, nb_stars, margin=margin)
			stars = astro.fit_stars(image, stars, fit_area, full_info=True)

			fwhm_1 = []
			fwhm_2 = []
			
			for xy in stars:
				#print(xy)
				fwhm_1.append(xy[5])
				fwhm_2.append(xy[6])
				
			print("                   FWHM small = %.2f" % np.ma.median(fwhm_1))
			print("                   FWHM large = %.2f" % np.ma.median(fwhm_2))
