# -*- coding: iso_8859_1 -*-

from aspylib import astrometry, astro, conf
import matplotlib.pyplot as plt

#------------------------------------------------------------------------------------
#	Purpose
#------------------------------------------------------------------------------------
#
#	Downloads USNO-B1 catalog information from the Vizier service
#
#------------------------------------------------------------------------------------
#	Input parameters
#------------------------------------------------------------------------------------

catalog = 'USNO-B1'
position = [56., 24.]		#[alpha, delta] in degrees
conesize = [600., 420.]		#[boxsize_alpha, boxsize_delta] in arcmin
constraint = 'B1mag<=11'

#------------------------------------------------------------------------------------
#	Script
#------------------------------------------------------------------------------------

#------ retrieving information from Vizier ------
astrometry.send_query_vizier(catalog, position, conesize, constraint)
stars = astrometry.read_votable(conf.folder+"vizier.xml")

#------ printing information --------------------
print("")
print(len(stars)," stars downloaded")
print("")
print("catalog fields:")
print(stars.dtype.names)

#------ generating sky map ----------------------
plt.figure()
plt.scatter(stars['RAJ2000'],stars['DEJ2000'],s=4*(12-stars['B1mag']))
plt.grid()
plt.xlim([52,60])
plt.ylim([22,27])
ax = plt.gca() 
ax.set_xlim(ax.get_xlim()[::-1])
plt.show()
